/*===========================================================================*/
/*   (Cfa/walk.scm)                                                          */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Cfa/walk.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_CFA_WALK_TYPE_DEFINITIONS
#define BGL_CFA_WALK_TYPE_DEFINITIONS
#endif													// BGL_CFA_WALK_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	BGL_IMPORT obj_t bgl_display_obj(obj_t, obj_t);
	extern obj_t BGl_declarezd2approxzd2setsz12z12zzcfa_approxz00(void);
	BGL_IMPORT bool_t BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00(obj_t);
	static obj_t BGl_objectzd2initzd2zzcfa_walkz00(void);
	extern obj_t BGl_typezd2settingsz12zc0zzcfa_typez00(obj_t);
	BGL_IMPORT bool_t BGl_2ze3ze3zz__r4_numbers_6_5z00(obj_t, obj_t);
	extern obj_t BGl_shrinkifyz12z12zzast_shrinkifyz00(obj_t);
	static obj_t BGl_appendzd221011zd2zzcfa_walkz00(obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzcfa_walkz00(void);
	extern obj_t BGl_specializa7ez12zb5zzcfa_specializa7eza7(obj_t);
	extern obj_t BGl_closurezd2optimiza7ationz12z67zzcfa_closurez00(obj_t);
	extern obj_t BGl_vectorzd2ze3tvectorz12z23zzcfa_tvectorz00(obj_t);
	extern obj_t BGl_cfazd2iteratezd2tozd2fixpointz12zc0zzcfa_iteratez00(obj_t);
	static obj_t BGl_gczd2rootszd2initz00zzcfa_walkz00(void);
	extern obj_t BGl_za2currentzd2passza2zd2zzengine_passz00;
	extern obj_t BGl_showzd2cfazd2nbzd2iterationszd2zzcfa_showz00(void);
	extern obj_t BGl_verbosez00zztools_speekz00(obj_t, obj_t);
	static obj_t BGl_requirezd2initializa7ationz75zzcfa_walkz00 = BUNSPEC;
	extern obj_t BGl_internalzd2errorzd2zztools_errorz00(obj_t, obj_t, obj_t);
	static obj_t BGl_genericzd2initzd2zzcfa_walkz00(void);
	extern obj_t BGl_collectzd2allzd2approxz12z12zzcfa_collectz00(obj_t);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	extern obj_t BGl_setzd2initialzd2approxz12z12zzcfa_setupz00(obj_t);
	extern obj_t BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00;
	extern obj_t BGl_removezd2varzd2zzast_removez00(obj_t, obj_t);
	extern obj_t BGl_showzd2cfazd2resultsz00zzcfa_showz00(obj_t);
	BGL_IMPORT obj_t BGl_exitz00zz__errorz00(obj_t);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzcfa_walkz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_arithmeticz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_pairz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_tvectorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_specializa7eza7(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_closurez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_approxz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_info3z00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_info2z00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_infoz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_showz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_iteratez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_setupz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcfa_collectz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzwrite_astz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_shrinkifyz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_removez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_shapez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_tracez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_passz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_errorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_speekz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	static obj_t BGl_z62cfazd2walkz12za2zzcfa_walkz00(obj_t, obj_t);
	static obj_t BGl_cnstzd2initzd2zzcfa_walkz00(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzcfa_walkz00(void);
	static obj_t BGl_importedzd2moduleszd2initz00zzcfa_walkz00(void);
	BGL_EXPORTED_DECL obj_t BGl_cfazd2walkz12zc0zzcfa_walkz00(obj_t);
	static obj_t __cnst[3];


	extern obj_t BGl_unpatchzd2pairzd2setz12zd2envzc0zzcfa_pairz00;
	   
		 
		DEFINE_STRING(BGl_string2005z00zzcfa_walkz00,
		BgL_bgl_string2005za700za7za7c2016za7, "Cfa", 3);
	      DEFINE_STRING(BGl_string2006z00zzcfa_walkz00,
		BgL_bgl_string2006za700za7za7c2017za7, "   . ", 5);
	      DEFINE_STRING(BGl_string2007z00zzcfa_walkz00,
		BgL_bgl_string2007za700za7za7c2018za7, "failure during prelude hook", 27);
	      DEFINE_STRING(BGl_string2008z00zzcfa_walkz00,
		BgL_bgl_string2008za700za7za7c2019za7, " error", 6);
	      DEFINE_STRING(BGl_string2009z00zzcfa_walkz00,
		BgL_bgl_string2009za700za7za7c2020za7, "s", 1);
	      DEFINE_STRING(BGl_string2010z00zzcfa_walkz00,
		BgL_bgl_string2010za700za7za7c2021za7, "", 0);
	      DEFINE_STRING(BGl_string2011z00zzcfa_walkz00,
		BgL_bgl_string2011za700za7za7c2022za7, " occured, ending ...", 20);
	      DEFINE_STRING(BGl_string2012z00zzcfa_walkz00,
		BgL_bgl_string2012za700za7za7c2023za7, "failure during postlude hook", 28);
	      DEFINE_STRING(BGl_string2013z00zzcfa_walkz00,
		BgL_bgl_string2013za700za7za7c2024za7, "cfa_walk", 8);
	      DEFINE_STRING(BGl_string2014z00zzcfa_walkz00,
		BgL_bgl_string2014za700za7za7c2025za7,
		"(stop-closure-cache unpatch-vector-set! unpatch-pair-set!) (cfa inline) pass-started ",
		85);
	extern obj_t BGl_unpatchzd2vectorzd2setz12zd2envzc0zzcfa_tvectorz00;
	   
		 
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_cfazd2walkz12zd2envz12zzcfa_walkz00,
		BgL_bgl_za762cfaza7d2walkza7122026za7, BGl_z62cfazd2walkz12za2zzcfa_walkz00,
		0L, BUNSPEC, 1);
	extern obj_t BGl_stopzd2closurezd2cachezd2envzd2zzcfa_closurez00;

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		     ADD_ROOT((void *) (&BGl_requirezd2initializa7ationz75zzcfa_walkz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzcfa_walkz00(long
		BgL_checksumz00_4049, char *BgL_fromz00_4050)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzcfa_walkz00))
				{
					BGl_requirezd2initializa7ationz75zzcfa_walkz00 = BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzcfa_walkz00();
					BGl_libraryzd2moduleszd2initz00zzcfa_walkz00();
					BGl_cnstzd2initzd2zzcfa_walkz00();
					BGl_importedzd2moduleszd2initz00zzcfa_walkz00();
					return BGl_methodzd2initzd2zzcfa_walkz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
				"cfa_walk");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__errorz00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L, "cfa_walk");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"cfa_walk");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			{	/* Cfa/walk.scm 24 */
				obj_t BgL_cportz00_4038;

				{	/* Cfa/walk.scm 24 */
					obj_t BgL_stringz00_4045;

					BgL_stringz00_4045 = BGl_string2014z00zzcfa_walkz00;
					{	/* Cfa/walk.scm 24 */
						obj_t BgL_startz00_4046;

						BgL_startz00_4046 = BINT(0L);
						{	/* Cfa/walk.scm 24 */
							obj_t BgL_endz00_4047;

							BgL_endz00_4047 =
								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_4045)));
							{	/* Cfa/walk.scm 24 */

								BgL_cportz00_4038 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_4045, BgL_startz00_4046, BgL_endz00_4047);
				}}}}
				{
					long BgL_iz00_4039;

					BgL_iz00_4039 = 2L;
				BgL_loopz00_4040:
					if ((BgL_iz00_4039 == (-1L)))
						{	/* Cfa/walk.scm 24 */
							return BUNSPEC;
						}
					else
						{	/* Cfa/walk.scm 24 */
							{	/* Cfa/walk.scm 24 */
								obj_t BgL_arg2015z00_4041;

								{	/* Cfa/walk.scm 24 */

									{	/* Cfa/walk.scm 24 */
										obj_t BgL_locationz00_4043;

										BgL_locationz00_4043 = BBOOL(((bool_t) 0));
										{	/* Cfa/walk.scm 24 */

											BgL_arg2015z00_4041 =
												BGl_readz00zz__readerz00(BgL_cportz00_4038,
												BgL_locationz00_4043);
										}
									}
								}
								{	/* Cfa/walk.scm 24 */
									int BgL_tmpz00_4076;

									BgL_tmpz00_4076 = (int) (BgL_iz00_4039);
									CNST_TABLE_SET(BgL_tmpz00_4076, BgL_arg2015z00_4041);
							}}
							{	/* Cfa/walk.scm 24 */
								int BgL_auxz00_4044;

								BgL_auxz00_4044 = (int) ((BgL_iz00_4039 - 1L));
								{
									long BgL_iz00_4081;

									BgL_iz00_4081 = (long) (BgL_auxz00_4044);
									BgL_iz00_4039 = BgL_iz00_4081;
									goto BgL_loopz00_4040;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			return bgl_gc_roots_register();
		}

	}



/* append-21011 */
	obj_t BGl_appendzd221011zd2zzcfa_walkz00(obj_t BgL_l1z00_1, obj_t BgL_l2z00_2)
	{
		{
			if (NULLP(BgL_l1z00_1))
				{
					return BgL_l2z00_2;
				}
			else
				{
					obj_t BgL_headz00_3410;

					BgL_headz00_3410 = MAKE_YOUNG_PAIR(BNIL, BgL_l2z00_2);
					{
						obj_t BgL_prevz00_3411;
						obj_t BgL_tailz00_3412;

						BgL_prevz00_3411 = BgL_headz00_3410;
						BgL_tailz00_3412 = BgL_l1z00_1;
					BgL_loopz00_3413:
						if (PAIRP(BgL_tailz00_3412))
							{
								obj_t BgL_newzd2prevzd2_3415;

								BgL_newzd2prevzd2_3415 =
									MAKE_YOUNG_PAIR(CAR(BgL_tailz00_3412), BgL_l2z00_2);
								SET_CDR(BgL_prevz00_3411, BgL_newzd2prevzd2_3415);
								{
									obj_t BgL_tailz00_4093;
									obj_t BgL_prevz00_4092;

									BgL_prevz00_4092 = BgL_newzd2prevzd2_3415;
									BgL_tailz00_4093 = CDR(BgL_tailz00_3412);
									BgL_tailz00_3412 = BgL_tailz00_4093;
									BgL_prevz00_3411 = BgL_prevz00_4092;
									goto BgL_loopz00_3413;
								}
							}
						else
							{
								BNIL;
							}
						return CDR(BgL_headz00_3410);
					}
				}
		}

	}



/* cfa-walk! */
	BGL_EXPORTED_DEF obj_t BGl_cfazd2walkz12zc0zzcfa_walkz00(obj_t
		BgL_globalsz00_3)
	{
		{	/* Cfa/walk.scm 62 */
			{	/* Cfa/walk.scm 63 */
				obj_t BgL_list1578z00_3418;

				{	/* Cfa/walk.scm 63 */
					obj_t BgL_arg1581z00_3419;

					{	/* Cfa/walk.scm 63 */
						obj_t BgL_arg1587z00_3420;

						BgL_arg1587z00_3420 =
							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
						BgL_arg1581z00_3419 =
							MAKE_YOUNG_PAIR(BGl_string2005z00zzcfa_walkz00,
							BgL_arg1587z00_3420);
					}
					BgL_list1578z00_3418 =
						MAKE_YOUNG_PAIR(BGl_string2006z00zzcfa_walkz00,
						BgL_arg1581z00_3419);
				}
				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1578z00_3418);
			}
			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
			BGl_za2currentzd2passza2zd2zzengine_passz00 =
				BGl_string2005z00zzcfa_walkz00;
			{	/* Cfa/walk.scm 63 */
				obj_t BgL_g1178z00_3421;

				BgL_g1178z00_3421 = BNIL;
				{
					obj_t BgL_hooksz00_3424;
					obj_t BgL_hnamesz00_3425;

					BgL_hooksz00_3424 = BgL_g1178z00_3421;
					BgL_hnamesz00_3425 = BNIL;
				BgL_zc3z04anonymousza31588ze3z87_3426:
					if (NULLP(BgL_hooksz00_3424))
						{	/* Cfa/walk.scm 63 */
							((obj_t) CNST_TABLE_REF(0));
						}
					else
						{	/* Cfa/walk.scm 63 */
							bool_t BgL_test2032z00_4107;

							{	/* Cfa/walk.scm 63 */
								obj_t BgL_fun1607z00_3433;

								BgL_fun1607z00_3433 = CAR(((obj_t) BgL_hooksz00_3424));
								BgL_test2032z00_4107 =
									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1607z00_3433));
							}
							if (BgL_test2032z00_4107)
								{	/* Cfa/walk.scm 63 */
									obj_t BgL_arg1593z00_3430;
									obj_t BgL_arg1597z00_3431;

									BgL_arg1593z00_3430 = CDR(((obj_t) BgL_hooksz00_3424));
									BgL_arg1597z00_3431 = CDR(((obj_t) BgL_hnamesz00_3425));
									{
										obj_t BgL_hnamesz00_4119;
										obj_t BgL_hooksz00_4118;

										BgL_hooksz00_4118 = BgL_arg1593z00_3430;
										BgL_hnamesz00_4119 = BgL_arg1597z00_3431;
										BgL_hnamesz00_3425 = BgL_hnamesz00_4119;
										BgL_hooksz00_3424 = BgL_hooksz00_4118;
										goto BgL_zc3z04anonymousza31588ze3z87_3426;
									}
								}
							else
								{	/* Cfa/walk.scm 63 */
									obj_t BgL_arg1605z00_3432;

									BgL_arg1605z00_3432 = CAR(((obj_t) BgL_hnamesz00_3425));
									BGl_internalzd2errorzd2zztools_errorz00
										(BGl_string2005z00zzcfa_walkz00,
										BGl_string2007z00zzcfa_walkz00, BgL_arg1605z00_3432);
								}
						}
				}
			}
			BGl_collectzd2allzd2approxz12z12zzcfa_collectz00(BgL_globalsz00_3);
			BGl_declarezd2approxzd2setsz12z12zzcfa_approxz00();
			BGl_setzd2initialzd2approxz12z12zzcfa_setupz00(BgL_globalsz00_3);
			{	/* Cfa/walk.scm 73 */
				obj_t BgL_iterationzd2rootszd2_3436;

				BgL_iterationzd2rootszd2_3436 =
					BGl_cfazd2iteratezd2tozd2fixpointz12zc0zzcfa_iteratez00
					(BgL_globalsz00_3);
				BGl_showzd2cfazd2nbzd2iterationszd2zzcfa_showz00();
				{	/* Cfa/walk.scm 77 */
					obj_t BgL_globalsz00_3437;

					BgL_globalsz00_3437 =
						BGl_removezd2varzd2zzast_removez00(
						((obj_t) CNST_TABLE_REF(1)), BgL_globalsz00_3);
					BGl_showzd2cfazd2resultsz00zzcfa_showz00(BgL_globalsz00_3437);
					{	/* Cfa/walk.scm 81 */
						obj_t BgL_additionalz00_3438;

						BgL_additionalz00_3438 =
							BGl_vectorzd2ze3tvectorz12z23zzcfa_tvectorz00
							(BgL_globalsz00_3437);
						BGl_closurezd2optimiza7ationz12z67zzcfa_closurez00
							(BgL_globalsz00_3437);
						BGl_typezd2settingsz12zc0zzcfa_typez00(BgL_globalsz00_3437);
						BGl_specializa7ez12zb5zzcfa_specializa7eza7(BgL_globalsz00_3437);
						{	/* Cfa/walk.scm 89 */
							obj_t BgL_valuez00_3439;

							BgL_valuez00_3439 =
								BGl_shrinkifyz12z12zzast_shrinkifyz00
								(BGl_appendzd221011zd2zzcfa_walkz00(BgL_additionalz00_3438,
									BgL_globalsz00_3437));
							if (((long)
									CINT(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00) >
									0L))
								{	/* Cfa/walk.scm 89 */
									{	/* Cfa/walk.scm 89 */
										obj_t BgL_port1559z00_3441;

										{	/* Cfa/walk.scm 89 */
											obj_t BgL_tmpz00_4141;

											BgL_tmpz00_4141 = BGL_CURRENT_DYNAMIC_ENV();
											BgL_port1559z00_3441 =
												BGL_ENV_CURRENT_ERROR_PORT(BgL_tmpz00_4141);
										}
										bgl_display_obj
											(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
											BgL_port1559z00_3441);
										bgl_display_string(BGl_string2008z00zzcfa_walkz00,
											BgL_port1559z00_3441);
										{	/* Cfa/walk.scm 89 */
											obj_t BgL_arg1611z00_3442;

											{	/* Cfa/walk.scm 89 */
												bool_t BgL_test2034z00_4146;

												if (BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00
													(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
													{	/* Cfa/walk.scm 89 */
														if (INTEGERP
															(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
															{	/* Cfa/walk.scm 89 */
																BgL_test2034z00_4146 =
																	(
																	(long)
																	CINT
																	(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00)
																	> 1L);
															}
														else
															{	/* Cfa/walk.scm 89 */
																BgL_test2034z00_4146 =
																	BGl_2ze3ze3zz__r4_numbers_6_5z00
																	(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
																	BINT(1L));
															}
													}
												else
													{	/* Cfa/walk.scm 89 */
														BgL_test2034z00_4146 = ((bool_t) 0);
													}
												if (BgL_test2034z00_4146)
													{	/* Cfa/walk.scm 89 */
														BgL_arg1611z00_3442 =
															BGl_string2009z00zzcfa_walkz00;
													}
												else
													{	/* Cfa/walk.scm 89 */
														BgL_arg1611z00_3442 =
															BGl_string2010z00zzcfa_walkz00;
													}
											}
											bgl_display_obj(BgL_arg1611z00_3442,
												BgL_port1559z00_3441);
										}
										bgl_display_string(BGl_string2011z00zzcfa_walkz00,
											BgL_port1559z00_3441);
										bgl_display_char(((unsigned char) 10),
											BgL_port1559z00_3441);
									}
									{	/* Cfa/walk.scm 89 */
										obj_t BgL_list1615z00_3446;

										BgL_list1615z00_3446 = MAKE_YOUNG_PAIR(BINT((-1L)), BNIL);
										BGL_TAIL return
											BGl_exitz00zz__errorz00(BgL_list1615z00_3446);
									}
								}
							else
								{	/* Cfa/walk.scm 89 */
									obj_t BgL_g1180z00_3447;
									obj_t BgL_g1181z00_3448;

									{	/* Cfa/walk.scm 89 */
										obj_t BgL_list1633z00_3461;

										{	/* Cfa/walk.scm 89 */
											obj_t BgL_arg1635z00_3462;

											{	/* Cfa/walk.scm 89 */
												obj_t BgL_arg1638z00_3463;

												BgL_arg1638z00_3463 =
													MAKE_YOUNG_PAIR
													(BGl_unpatchzd2pairzd2setz12zd2envzc0zzcfa_pairz00,
													BNIL);
												BgL_arg1635z00_3462 =
													MAKE_YOUNG_PAIR
													(BGl_unpatchzd2vectorzd2setz12zd2envzc0zzcfa_tvectorz00,
													BgL_arg1638z00_3463);
											}
											BgL_list1633z00_3461 =
												MAKE_YOUNG_PAIR
												(BGl_stopzd2closurezd2cachezd2envzd2zzcfa_closurez00,
												BgL_arg1635z00_3462);
										}
										BgL_g1180z00_3447 = BgL_list1633z00_3461;
									}
									BgL_g1181z00_3448 = ((obj_t) CNST_TABLE_REF(2));
									{
										obj_t BgL_hooksz00_3450;
										obj_t BgL_hnamesz00_3451;

										BgL_hooksz00_3450 = BgL_g1180z00_3447;
										BgL_hnamesz00_3451 = BgL_g1181z00_3448;
									BgL_zc3z04anonymousza31616ze3z87_3452:
										if (NULLP(BgL_hooksz00_3450))
											{	/* Cfa/walk.scm 89 */
												return BgL_valuez00_3439;
											}
										else
											{	/* Cfa/walk.scm 89 */
												bool_t BgL_test2038z00_4168;

												{	/* Cfa/walk.scm 89 */
													obj_t BgL_fun1632z00_3459;

													BgL_fun1632z00_3459 =
														CAR(((obj_t) BgL_hooksz00_3450));
													BgL_test2038z00_4168 =
														CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1632z00_3459));
												}
												if (BgL_test2038z00_4168)
													{	/* Cfa/walk.scm 89 */
														obj_t BgL_arg1625z00_3456;
														obj_t BgL_arg1626z00_3457;

														BgL_arg1625z00_3456 =
															CDR(((obj_t) BgL_hooksz00_3450));
														BgL_arg1626z00_3457 =
															CDR(((obj_t) BgL_hnamesz00_3451));
														{
															obj_t BgL_hnamesz00_4180;
															obj_t BgL_hooksz00_4179;

															BgL_hooksz00_4179 = BgL_arg1625z00_3456;
															BgL_hnamesz00_4180 = BgL_arg1626z00_3457;
															BgL_hnamesz00_3451 = BgL_hnamesz00_4180;
															BgL_hooksz00_3450 = BgL_hooksz00_4179;
															goto BgL_zc3z04anonymousza31616ze3z87_3452;
														}
													}
												else
													{	/* Cfa/walk.scm 89 */
														obj_t BgL_arg1631z00_3458;

														BgL_arg1631z00_3458 =
															CAR(((obj_t) BgL_hnamesz00_3451));
														return
															BGl_internalzd2errorzd2zztools_errorz00
															(BGl_za2currentzd2passza2zd2zzengine_passz00,
															BGl_string2012z00zzcfa_walkz00,
															BgL_arg1631z00_3458);
													}
											}
									}
								}
						}
					}
				}
			}
		}

	}



/* &cfa-walk! */
	obj_t BGl_z62cfazd2walkz12za2zzcfa_walkz00(obj_t BgL_envz00_4033,
		obj_t BgL_globalsz00_4034)
	{
		{	/* Cfa/walk.scm 62 */
			return BGl_cfazd2walkz12zc0zzcfa_walkz00(BgL_globalsz00_4034);
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzcfa_walkz00(void)
	{
		{	/* Cfa/walk.scm 24 */
			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzast_removez00(383247627L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzast_shrinkifyz00(45200572L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzwrite_astz00(250486252L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_collectz00(220306886L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_setupz00(168272122L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_iteratez00(131412063L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_showz00(391833753L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_infoz00(3788352L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_info2z00(0L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_info3z00(0L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_approxz00(285971837L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_typez00(93933605L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_closurez00(188963689L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_specializa7eza7(374743292L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_tvectorz00(324810626L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			BGl_modulezd2initializa7ationz75zzcfa_pairz00(37668556L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
			return
				BGl_modulezd2initializa7ationz75zzcfa_arithmeticz00(185547682L,
				BSTRING_TO_STRING(BGl_string2013z00zzcfa_walkz00));
		}

	}

#ifdef __cplusplus
}
#endif
